summaryrefslogtreecommitdiff
path: root/addons/website/static/src
diff options
context:
space:
mode:
authorRaphael Collet <rco@odoo.com>2020-10-09 09:36:53 +0000
committerRaphael Collet <rco@odoo.com>2020-10-12 12:24:09 +0000
commitec50c426d7c2a17c7b72e64adab65eda6328e163 (patch)
treec0dabe05574d825bf0a191996ee91168518e25da /addons/website/static/src
parent5c0fca662279702115b5e61c8227f82086693e38 (diff)
[FIX] core: optimize first snaphot in onchange
This patch speeds up the performance of method `onchange`. Our use-case is an invoice with 300 lines, where we modify the unit price or quantity on several lines. Each modification triggers a call to `onchange` on the invoice itself. The latter call went from 1.3 to 0.8 seconds, which represents a speedup of 30% to 40%. In the implementation of `onchange`, the first snapshot is preceded by a "prefetching" phase, where the lines of x2many fields are read, so that the fields of unmodified lines are in cache. This is useful because the fields of those lines are not sent by the client, which only sends ids. This prefetching represents more than 40% of the duration of `onchange`, in our use-case. The prefetching is inefficient for several reasons. First, it uses `mapped`, which formats data that is actually never used. Second, it accesses new records that have the actual lines as origin. And on those records, computed stored fields are not taken from the origin record, but are (uselessly) computed instead. We have optimized the prefetching in the following way. It now reads stored fields on the actual lines (using `_read` to avoid formatting), then copies the cache of those fields on the corresponding new lines (to avoid useless computations). This makes the prefetching about 10 times faster! closes odoo/odoo#59744 X-original-commit: d39d61d763f4cb3019a78b202f7981c4f2e14d60 Signed-off-by: Raphael Collet (rco) <rco@openerp.com>
Diffstat (limited to 'addons/website/static/src')
0 files changed, 0 insertions, 0 deletions